<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassXC</source>
        <translation>關於 KeePassXC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>貢獻者</translation>
    </message>
    <message>
        <source>Debug Info</source>
        <translation>除錯資訊</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>複製到剪貼簿</translation>
    </message>
    <message>
        <source>Version %1
</source>
        <translation>版本 %1
</translation>
    </message>
    <message>
        <source>Revision: %1</source>
        <translation>修訂：%1</translation>
    </message>
    <message>
        <source>Libraries:</source>
        <translation>函式庫：</translation>
    </message>
    <message>
        <source>Operating system: %1
CPU architecture: %2
Kernel: %3 %4</source>
        <translation>作業系統：%1
處裡器架構：%2
核心：%3 %4</translation>
    </message>
    <message>
        <source>Enabled extensions:</source>
        <translation>已啟用的擴充元件：</translation>
    </message>
    <message>
        <source>Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</source>
        <translation>回報 Bug 請至：&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</translation>
    </message>
    <message>
        <source>KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassXC 遵循 GNU 通用公共許可證 (GPL) 第二版 或（依你的需求）以第三版發行。</translation>
    </message>
    <message>
        <source>Project Maintainers:</source>
        <translation>專案維護者：</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;See Contributions on GitHub&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;在 GitHub 上看看有哪些貢獻者&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Include the following information whenever you report a bug:</source>
        <translation>回報 Bug 時會包含以下資訊：</translation>
    </message>
    <message>
        <source>Distribution: %1</source>
        <translation>散佈：%1</translation>
    </message>
</context>
<context>
    <name>AccessControlDialog</name>
    <message>
        <source>Remember this decision</source>
        <translation>記住此決定</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>允許</translation>
    </message>
    <message>
        <source>Deny</source>
        <translation>禁止</translation>
    </message>
    <message>
        <source>%1 has requested access to passwords for the following item(s).
Please select whether you want to allow access.</source>
        <translation>%1 要求存取下列項目的密碼。
請選擇是否允許存取。</translation>
    </message>
    <message>
        <source>KeePassXC HTTP Confirm Access</source>
        <translation>KeePassXC HTTP 確認存取</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>無法找到符合視窗標題的項目</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>自動輸入 - KeePassXC</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>視窗</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>序列</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>預設序列</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>選擇要自動輸入的項目</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>自動輸入 - KeePassXC</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>輸入密碼：</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>再次輸入密碼：</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>建立</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>金鑰檔案</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有檔案</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>建立金鑰檔案……</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>無法建立金鑰檔案： </translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>選擇金鑰檔案</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>真的要使用空白密碼？</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>填寫的密碼不一致。</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>無法將 %1 設為金鑰檔案：
%2</translation>
    </message>
    <message>
        <source>&amp;Key file</source>
        <translation>金鑰檔案 (&amp;K)</translation>
    </message>
    <message>
        <source>Cha&amp;llenge Response</source>
        <translation>挑戰回應</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>重新整理</translation>
    </message>
    <message>
        <source>Empty password</source>
        <translation>清空密碼</translation>
    </message>
    <message>
        <source>Changing master key failed: no YubiKey inserted.</source>
        <translation>挑戰主金鑰失敗：沒有插入 YubiKey</translation>
    </message>
</context>
<context>
    <name>CloneDialog</name>
    <message>
        <source>Clone Options</source>
        <translation>複製選項</translation>
    </message>
    <message>
        <source>Replace username and password with references</source>
        <translation>以引用資料取代使用者名稱與密碼</translation>
    </message>
    <message>
        <source>Copy history</source>
        <translation>複製歷史記錄</translation>
    </message>
    <message>
        <source>Append &apos; - Clone&apos; to title</source>
        <translation>在標題後追加「 - 複製」字樣</translation>
    </message>
</context>
<context>
    <name>CsvImportWidget</name>
    <message>
        <source>Import CSV fields</source>
        <translation>匯入 CSV 欄位</translation>
    </message>
    <message>
        <source>filename</source>
        <translation>檔案名稱</translation>
    </message>
    <message>
        <source>size, rows, columns</source>
        <translation>尺寸、行、列</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>編碼</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>編解碼器</translation>
    </message>
    <message>
        <source>Text is qualified by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fields are separated by</source>
        <translation>欄位分隔符號</translation>
    </message>
    <message>
        <source>Comments start with</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>First record has field names</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Number of headers line to discard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Consider &apos;\&apos; an escape character</source>
        <translation>請以「\」作為跳脫符號</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <source>Column layout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not present in CSV file</source>
        <translation>不在 CSV 檔案內</translation>
    </message>
    <message>
        <source>Empty fieldname </source>
        <translation>清空檔名 </translation>
    </message>
    <message>
        <source>column </source>
        <translation>列 </translation>
    </message>
    <message>
        <source>Imported from CSV file</source>
        <translation>已從 CSV 檔匯入</translation>
    </message>
    <message>
        <source>Original data: </source>
        <translation>原始資料： </translation>
    </message>
    <message>
        <source>Error(s) detected in CSV file !</source>
        <translation>CSV 檔中檢測到錯誤！</translation>
    </message>
    <message>
        <source> more messages skipped]</source>
        <translation> 等訊息已跳過]</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>CSV import: writer has errors:
</source>
        <translation>CSV 匯入：寫入器錯誤：
</translation>
    </message>
</context>
<context>
    <name>CsvImportWizard</name>
    <message>
        <source>Import CSV file</source>
        <translation>匯入 CSV 檔</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>無法計算主金鑰</translation>
    </message>
</context>
<context>
    <name>CsvParserModel</name>
    <message>
        <source> byte, </source>
        <translation> 位元組， </translation>
    </message>
    <message>
        <source> rows, </source>
        <translation> 行， </translation>
    </message>
    <message>
        <source> columns</source>
        <translation> 列</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>輸入主金鑰</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>金鑰檔案：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>瀏覽</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>無法開啟資料庫。</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>無法開啟金鑰檔案</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有檔案</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>金鑰檔案</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>選擇金鑰檔案</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>重新整理</translation>
    </message>
    <message>
        <source>Challenge Response:</source>
        <translation>挑戰驗證：</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>修復資料庫</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>無法開啟金鑰檔案</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>資料庫正常開啟。什麼都不做。</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>無法開啟資料庫。</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>資料庫已成功修復，你現在可以直接儲存。</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>無法開啟資料庫</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>資料庫名稱：</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>資料庫描述：</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>加密轉換次數：</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>預設的使用者名稱：</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>效能測試</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>最大歷史記錄項目：</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>最大歷史記錄大小：</translation>
    </message>
    <message>
        <source>Use recycle bin</source>
        <translation>使用回收桶</translation>
    </message>
    <message>
        <source>AES:  256 Bit   (default)</source>
        <translation>AES：256 位元（預設）</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish：256 位元</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>演算法：</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>根</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 資料庫</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有檔案</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>開啟資料庫</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>找不到檔案！</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>開啟 KeePass 1 資料庫</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 資料庫</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>所有檔案 (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>關閉？</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>儲存修改？</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>「%1」已修改。
儲存變更？</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>寫入資料庫失敗。</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>資料庫另存為</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>新的資料庫</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>已鎖定</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>鎖定資料庫</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>目前正在編輯中，所以無法鎖定資料庫。
請按取消以完成修改或捨棄修改。</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>資料庫尚未儲存。
可以先儲存資料庫或是停止鎖定資料庫</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>此資料庫已修改。
要在鎖定之前儲存資料庫？
不然則會遺失所有修改。</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>「%1」 正在編輯模式中。
是否要捨棄變更並關閉？</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>將資料庫輸出成 CSV 檔案</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV 檔案</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>寫入 CSV 檔案失敗。</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>無法開啟資料庫。</translation>
    </message>
    <message>
        <source>Merge database</source>
        <translation>合併資料庫</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassXC.
Do you want to save it anyway?</source>
        <translation>欲儲存的資料庫已由其他 KeePassXC 程式鎖定。
仍要繼續儲存？</translation>
    </message>
    <message>
        <source>Passwords</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Database already opened</source>
        <translation>資料庫已開啟</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassXC.

Do you want to open it anyway?</source>
        <translation>欲開啟的資料庫已由其他 KeePassXC 程式鎖定。

仍要繼續開啟？</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>以唯讀模式開啟</translation>
    </message>
    <message>
        <source>File opened in read only mode.</source>
        <translation>已將檔案以唯讀模式開啟。</translation>
    </message>
    <message>
        <source>Open CSV file</source>
        <translation>開啟 CSV 檔</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>變更主金鑰</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>刪除項目？</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>真的要永久刪除「%1」？</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>刪除項目？</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>真的要永久刪除 %1 個項目？</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>將項目移到回收桶？</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>真的要將 %n 個項目移到回收桶？</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>刪除群組？</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>真的要永遠刪除「%1」群組？</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>無法計算主金鑰</translation>
    </message>
    <message>
        <source>Move entry to recycle bin?</source>
        <translation>將項目移到回收桶？</translation>
    </message>
    <message>
        <source>Do you really want to move entry &quot;%1&quot; to the recycle bin?</source>
        <translation>真的要將「%1」移到回收桶？</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>搜尋中……</translation>
    </message>
    <message>
        <source>No current database.</source>
        <translation>無目前資料庫。</translation>
    </message>
    <message>
        <source>No source database, nothing to do.</source>
        <translation>無來源資料庫，什麼都不做。</translation>
    </message>
    <message>
        <source>Search Results (%1)</source>
        <translation>搜尋結果 (%1)</translation>
    </message>
    <message>
        <source>No Results</source>
        <translation>無結果</translation>
    </message>
    <message>
        <source>Execute command?</source>
        <translation>執行命令？</translation>
    </message>
    <message>
        <source>Do you really want to execute the following command?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</source>
        <translation>真的要執行下列命令？&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>記住我的選擇</translation>
    </message>
    <message>
        <source>Autoreload Request</source>
        <translation>自動重新讀取請求</translation>
    </message>
    <message>
        <source>The database file has changed. Do you want to load the changes?</source>
        <translation>資料庫檔案已變更。讀取變更？</translation>
    </message>
    <message>
        <source>Merge Request</source>
        <translation>合併請求</translation>
    </message>
    <message>
        <source>The database file has changed and you have unsaved changes.Do you want to merge your changes?</source>
        <translation>資料庫檔案已變更，且有尚未儲存的變更。合併變更？</translation>
    </message>
    <message>
        <source>Could not open the new database file while attempting to autoreload this database.</source>
        <translation>自動重新讀取此資料庫時，無法開啟新資料庫檔案。</translation>
    </message>
    <message>
        <source>Empty recycle bin?</source>
        <translation>清空回收桶？</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete everything from your recycle bin?</source>
        <translation>確定要永久刪除回收桶內的項目？</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>項目</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>進階</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>圖示</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>自動輸入</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>屬性</translation>
    </message>
    <message>
        <source>History</source>
        <translation>歷史記錄</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>項目歷史記錄</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>增加項目</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>編輯項目</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>填寫的密碼不一致。</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>新的屬性</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>選擇檔案</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>無法開啟檔案</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>儲存附件</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>無法儲存附件：
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>明天</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n 個禮拜</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n 個月</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 年</translation>
    </message>
    <message>
        <source>Confirm Remove</source>
        <translation>確認移除</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attribute?</source>
        <translation>確定要移除此屬性？</translation>
    </message>
    <message>
        <source>[PROTECTED] Press reveal to view or edit</source>
        <translation>[受保護的內容] 請按「揭示」以檢視或編輯</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attachment?</source>
        <translation>確定要移除此附件？</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>額外屬性</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>加入</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>附件</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>編輯名稱</translation>
    </message>
    <message>
        <source>Protect</source>
        <translation>保護</translation>
    </message>
    <message>
        <source>Reveal</source>
        <translation>揭示</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>啟用此項目的自動輸入</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>視窗標題：</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the &amp;group</source>
        <translation>從群組中繼承預設的自動輸入序列 (&amp;G)</translation>
    </message>
    <message>
        <source>&amp;Use custom Auto-Type sequence:</source>
        <translation>使用自訂的自動輸入序列 (&amp;U)：</translation>
    </message>
    <message>
        <source>Use default se&amp;quence</source>
        <translation>使用預設序列 (&amp;Q)</translation>
    </message>
    <message>
        <source>Set custo&amp;m sequence:</source>
        <translation>設定自訂序列 (&amp;M)：</translation>
    </message>
    <message>
        <source>Window Associations</source>
        <translation>視窗關聯</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>顯示</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>還原</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>刪除全部</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>使用者名稱：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>重複：</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>網址：</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>過期</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>預設</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>附註：</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>群組</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>圖示</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>屬性</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>加入群組</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>編輯群組</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>啟用</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>繼承自上層群組 (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>附註</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>過期</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>自動輸入</translation>
    </message>
    <message>
        <source>&amp;Use default Auto-Type sequence of parent group</source>
        <translation>使用上層群組預設的自動輸入序列 (&amp;U)</translation>
    </message>
    <message>
        <source>Set default Auto-Type se&amp;quence</source>
        <translation>設定預設自動輸入序列 (&amp;Q)</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Add custom icon</source>
        <translation>加入自訂圖示</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>刪除自訂圖示</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有檔案</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>選擇圖片</translation>
    </message>
    <message>
        <source>Download favicon</source>
        <translation>下載圖示</translation>
    </message>
    <message>
        <source>Unable to fetch favicon.</source>
        <translation>無法擷取圖示。</translation>
    </message>
    <message>
        <source>Can&apos;t read icon</source>
        <translation>無法讀取圖示</translation>
    </message>
    <message>
        <source>&amp;Use default icon</source>
        <translation>使用預設圖示 (&amp;U)</translation>
    </message>
    <message>
        <source>Use custo&amp;m icon</source>
        <translation>使用自訂圖示 (&amp;M)</translation>
    </message>
    <message>
        <source>Confirm Delete</source>
        <translation>確認刪除</translation>
    </message>
    <message>
        <source>This icon is used by %1 entries, and will be replaced by the default icon. Are you sure you want to delete it?</source>
        <translation>有 %1 個項目使用此圖示，並將以預設圖示取代。確定要刪除圖示？</translation>
    </message>
    <message>
        <source>Hint: You can enable Google as a fallback under Tools&gt;Settings&gt;Security</source>
        <translation>提示：可以啟用 Google 當作備案。選項請至 工具&gt;設定&gt;安全性</translation>
    </message>
    <message>
        <source>Custom icon already exists</source>
        <translation>自訂圖示已經存在</translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>已建立：</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>已修改：</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>已存取：</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid：</translation>
    </message>
</context>
<context>
    <name>Entry</name>
    <message>
        <source> - Clone</source>
        <translation> - 複製</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>最後編輯時間</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>網址</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>群組</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>網址</translation>
    </message>
    <message>
        <source>Ref: </source>
        <comment>Reference abbreviation</comment>
        <translation>引用： </translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>回收桶</translation>
    </message>
</context>
<context>
    <name>HttpPasswordGeneratorWidget</name>
    <message>
        <source>Length:</source>
        <translation>長度：</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>字元類型</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>大寫英文字母</translation>
    </message>
    <message>
        <source>A-Z</source>
        <translation>A-Z</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>小寫英文字母</translation>
    </message>
    <message>
        <source>a-z</source>
        <translation>a-z</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>數字</translation>
    </message>
    <message>
        <source>0-9</source>
        <translation>0-9</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>特殊字元</translation>
    </message>
    <message>
        <source>/*_&amp; ...</source>
        <translation>/*_&amp; ...</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>去除相似的字元</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>確保密碼包含每一組字元</translation>
    </message>
</context>
<context>
    <name>KMessageWidget</name>
    <message>
        <source>&amp;Close</source>
        <translation>關閉 (&amp;C)</translation>
    </message>
    <message>
        <source>Close message</source>
        <translation>關閉訊息</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>匯入 KeePass 1 資料庫</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>無法開啟資料庫。</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>無法讀取金鑰檔案。</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>並非 KeePass 資料庫。</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>不支援的加密演算法。</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>不支援的 KeePass 資料庫版本。</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>根</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>無法計算主金鑰</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>金鑰不正確或是資料庫損壞。</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>並非 KeePass 資料庫。</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>不支援的 KeePass 資料庫版本。</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>金鑰不正確或是資料庫損壞。</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>無法計算主金鑰</translation>
    </message>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database...'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>選擇的檔案是舊的 KeePass 1 資料庫 (.kdb)。

你可以點選 資料庫 &gt; 「匯入 KeePass 1 資料庫……」。
這是單向遷移。你無法用舊的 KeePassX 0.4 的版本開啟已匯入的資料庫。</translation>
    </message>
</context>
<context>
    <name>KeePass2Writer</name>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>無法計算主金鑰</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>測試加密函數時發生重大錯誤。</translation>
    </message>
    <message>
        <source>KeePassXC - Error</source>
        <translation>KeePassXC - 錯誤</translation>
    </message>
    <message>
        <source>The lock file could not be created. Single-instance mode disabled.</source>
        <translation>無法建立鎖定文件。已停用單一實例模式。</translation>
    </message>
    <message>
        <source>Another instance of KeePassXC is already running.</source>
        <translation>其他 KeePassXC 程式正在運行中。</translation>
    </message>
    <message>
        <source>Existing single-instance lock file is invalid. Launching new instance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open database</source>
        <translation>開啟資料庫</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>資料庫設定</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>將使用者名稱複製到剪貼簿</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>將密碼複製到剪貼簿</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>顯示工具列</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>唯讀</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>切換視窗</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 資料庫</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有檔案</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>儲存已修復的資料庫</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>寫入資料庫失敗。</translation>
    </message>
    <message>
        <source>&amp;Recent databases</source>
        <translation>最近的資料庫 (&amp;R)</translation>
    </message>
    <message>
        <source>E&amp;ntries</source>
        <translation>項目 (&amp;N)</translation>
    </message>
    <message>
        <source>Copy att&amp;ribute to clipboard</source>
        <translation>複製屬性到剪貼簿 (&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>群組 (&amp;G)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>檢視 (&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>離開 (&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於 (&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Save database</source>
        <translation>儲存資料庫 (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Close database</source>
        <translation>關閉資料庫 (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;New database</source>
        <translation>新的資料庫 (&amp;N)</translation>
    </message>
    <message>
        <source>Merge from KeePassX database</source>
        <translation>從 KeePassX 資料庫合併</translation>
    </message>
    <message>
        <source>&amp;Add new entry</source>
        <translation>新增項目 (&amp;A)</translation>
    </message>
    <message>
        <source>&amp;View/Edit entry</source>
        <translation>檢視/編輯項目 (&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Delete entry</source>
        <translation>刪除項目 (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Add new group</source>
        <translation>新增群組 (&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Edit group</source>
        <translation>編輯群組 (&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Delete group</source>
        <translation>刪除群組 (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Database settings</source>
        <translation>資料庫設定 (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Clone entry</source>
        <translation>複製項目 (&amp;C)</translation>
    </message>
    <message>
        <source>Timed one-time password</source>
        <translation>定時型一次性密碼 (TOTP)</translation>
    </message>
    <message>
        <source>Copy &amp;TOTP</source>
        <translation>複製 TOTP (&amp;T)</translation>
    </message>
    <message>
        <source>Show TOTP</source>
        <translation>顯示 TOTP</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>尋找 (&amp;F)</translation>
    </message>
    <message>
        <source>Copy &amp;username</source>
        <translation>複製使用者名稱 (&amp;U)</translation>
    </message>
    <message>
        <source>Cop&amp;y password</source>
        <translation>複製密碼 (&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定 (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Perform Auto-Type</source>
        <translation>執行自動輸入 (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>開啟網址 (&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Lock databases</source>
        <translation>鎖定資料庫 (&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>標題 (&amp;T)</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>網址 (&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Notes</source>
        <translation>附註 (&amp;N)</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>密碼產生器</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>清除歷史記錄</translation>
    </message>
    <message>
        <source>&amp;Database</source>
        <translation>資料庫 (&amp;D)</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>匯入</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>工具 (&amp;T)</translation>
    </message>
    <message>
        <source>Empty recycle bin</source>
        <translation>清空回收桶</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>設定檔存取錯誤：%1</translation>
    </message>
    <message>
        <source>Quit KeePassXC</source>
        <translation>退出 KeePassXC</translation>
    </message>
    <message>
        <source>Please touch the button on your YubiKey!</source>
        <translation>請觸摸你 YubiKey 上的按鈕！</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>幫助 (&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Open database...</source>
        <translation>開啟資料庫…… (&amp;O)</translation>
    </message>
    <message>
        <source>Sa&amp;ve database as...</source>
        <translation>將資料庫儲存為…… (&amp;V)</translation>
    </message>
    <message>
        <source>Change &amp;master key...</source>
        <translation>變更主金鑰…… (&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Export to CSV file...</source>
        <translation>匯出到 CSV 檔案…… (&amp;E)</translation>
    </message>
    <message>
        <source>Import KeePass 1 database...</source>
        <translation>匯入 KeePass 1 資料庫……</translation>
    </message>
    <message>
        <source>Import CSV file...</source>
        <translation>匯入 CSV 檔……</translation>
    </message>
    <message>
        <source>Re&amp;pair database...</source>
        <translation>修復資料庫…… (&amp;P)</translation>
    </message>
    <message>
        <source>Set up TOTP...</source>
        <translation>安裝 TOTP</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>Dialog</source>
        <translation>對話方塊</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Sh&amp;ow a notification when credentials are requested</source>
        <translation>要求憑證時顯示通知 (&amp;O)</translation>
    </message>
    <message>
        <source>Sort matching entries by &amp;username</source>
        <translation>依使用者名稱排序符合項目 (&amp;U)</translation>
    </message>
    <message>
        <source>Re&amp;move all stored permissions from entries in active database</source>
        <translation>從目前的資料庫項目中移除所有權限。</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>進階</translation>
    </message>
    <message>
        <source>Always allow &amp;access to entries</source>
        <translation>總是允許存取項目 (&amp;A)</translation>
    </message>
    <message>
        <source>Always allow &amp;updating entries</source>
        <translation>總是允許更新項目 (&amp;U)</translation>
    </message>
    <message>
        <source>Searc&amp;h in all opened databases for matching entries</source>
        <translation>在所有開啟的資料庫內搜尋相符的項目 (&amp;H)</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>HTTP 埠：</translation>
    </message>
    <message>
        <source>Default port: 19455</source>
        <translation>預設埠：19455</translation>
    </message>
    <message>
        <source>Re&amp;quest to unlock the database if it is locked</source>
        <translation>若資料庫已鎖定，則請求解鎖 (&amp;Q)</translation>
    </message>
    <message>
        <source>Sort &amp;matching entries by title</source>
        <translation>依名稱排序符合項目 (&amp;M)</translation>
    </message>
    <message>
        <source>KeePassXC will listen to this port on 127.0.0.1</source>
        <translation>KeePassXC 會在 127.0.0.1 上監聽此埠</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports</source>
        <translation>無法綁定到特殊權限埠</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports below 1024!
Using default port 19455.</source>
        <translation>無法綁定到 1024 以下的特殊權限埠！
將使用預設埠 19455。</translation>
    </message>
    <message>
        <source>R&amp;emove all shared encryption keys from active database</source>
        <translation>從目前的資料庫移除所有共用的加密金鑰 (&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Return advanced string fields which start with &quot;KPH: &quot;</source>
        <translation>回傳 「KPH: 」 起首的進階文字欄位 (&amp;R)</translation>
    </message>
    <message>
        <source>Automatically creating or updating string fields is not supported.</source>
        <translation>不支援自動建立或更新文字欄位。</translation>
    </message>
    <message>
        <source>This is required for accessing your databases from ChromeIPass or PassIFox</source>
        <translation>啟用後才能讓 ChromeIPass 或 PassIFox 存取你的資料庫</translation>
    </message>
    <message>
        <source>Enable KeePassHTTP server</source>
        <translation>啟用 KeePassHTTP 伺服器</translation>
    </message>
    <message>
        <source>Only returns the best matches for a specific URL instead of all entries for the whole domain.</source>
        <translation>只回傳最佳的網址相符項目而非所有網址相符的項目。(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Return only best matching entries</source>
        <translation>只回傳最佳的相符項目 (&amp;R)</translation>
    </message>
    <message>
        <source>Only entries with the same scheme (http://, https://, ftp://, ...) are returned.</source>
        <translation>只顯示相同協定的項目。(http://, https://, ftp://, ...)</translation>
    </message>
    <message>
        <source>&amp;Match URL schemes</source>
        <translation>符合網址協定 (&amp;M)</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>密碼產生器</translation>
    </message>
    <message>
        <source>Only the selected database has to be connected with a client.</source>
        <translation>只有所選的資料庫能連接到客戶端。</translation>
    </message>
    <message>
        <source>The following options can be dangerous!
Change them only if you know what you are doing.</source>
        <translation>下列選項具有相當風險！
了解其作用前切勿變更。</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>字元類型</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>大寫英文字母</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>小寫英文字母</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>數字</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>特殊字元</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>去除相似的字元</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>strength</source>
        <translation>強度</translation>
    </message>
    <message>
        <source>entropy</source>
        <translation>entropy</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>長度 (&amp;L)：</translation>
    </message>
    <message>
        <source>Pick characters from every group</source>
        <translation>從每一組中選擇字元</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>產生</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>套用</translation>
    </message>
    <message>
        <source>Entropy: %1 bit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password Quality: %1</source>
        <translation>密碼素質：%1</translation>
    </message>
    <message>
        <source>Poor</source>
        <translation>極弱</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>較弱</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>較好</translation>
    </message>
    <message>
        <source>Excellent</source>
        <translation>極好</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Extended ASCII</source>
        <translation>擴展 ASCII 碼</translation>
    </message>
    <message>
        <source>Passphrase</source>
        <translation>密語</translation>
    </message>
    <message>
        <source>Wordlist:</source>
        <translation>詞彙表：</translation>
    </message>
    <message>
        <source>Word Count:</source>
        <translation>詞彙數：</translation>
    </message>
    <message>
        <source>Word Separator:</source>
        <translation>單詞分隔符號：</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>NULL device</source>
        <translation>NULL 裝置</translation>
    </message>
    <message>
        <source>error reading from device</source>
        <translation>從裝置讀取時出錯</translation>
    </message>
    <message>
        <source>file empty !
</source>
        <translation>檔案是空的！
</translation>
    </message>
    <message>
        <source>malformed string</source>
        <translation>格式不正確的字串</translation>
    </message>
    <message>
        <source>missing closing quote</source>
        <translation>缺少右引號</translation>
    </message>
    <message>
        <source>INTERNAL - unget lower bound exceeded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation>群組</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>標題</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>網址</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>附註</translation>
    </message>
    <message>
        <source>Browser Integration</source>
        <translation>瀏覽器整合</translation>
    </message>
    <message>
        <source>YubiKey[%1] Challenge Response - Slot %2 - %3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Press</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passive</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>進行壓縮時，內部 zlib 發生錯誤： </translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>寫入底層裝置時出錯： </translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>開啟底層裝置時出錯： </translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>讀取底層裝置時出錯： </translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>進行解壓縮時，內部 zlib 發生錯誤： </translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>此版本的 zlib 不支援 gzip 格式</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>內部 zlib 發生錯誤： </translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Case Sensitive</source>
        <translation>區分大小寫</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation>搜尋……</translation>
    </message>
    <message>
        <source>Limit search to selected group</source>
        <translation>限制只搜尋選定的群組</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <source>A shared encryption-key with the name &quot;%1&quot; already exists.
Do you want to overwrite it?</source>
        <translation>已存在名為「%1」的共用加密金鑰。
進行覆蓋？</translation>
    </message>
    <message>
        <source>Do you want to update the information in %1 - %2?</source>
        <translation>更新 %1 到 %2 的資訊？</translation>
    </message>
    <message>
        <source>The active database is locked!
Please unlock the selected database or choose another one which is unlocked.</source>
        <translation>目前的資料庫已鎖定！
請解鎖所選的資料庫或選擇其他已解鎖的資料庫。</translation>
    </message>
    <message>
        <source>Successfully removed %1 encryption-%2 from KeePassX/Http Settings.</source>
        <translation>成功從 KeePassX/Http Settings 移除 %1 encryption-%2。</translation>
    </message>
    <message>
        <source>No shared encryption-keys found in KeePassHttp Settings.</source>
        <translation>KeePassHttp Settings 中找不到共享加密金鑰。</translation>
    </message>
    <message>
        <source>The active database does not contain an entry of KeePassHttp Settings.</source>
        <translation>目前的資料庫沒有 KeePassHttp Settings 項目。</translation>
    </message>
    <message>
        <source>Removing stored permissions...</source>
        <translation>正在移除所有已儲存的權限……</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>中止</translation>
    </message>
    <message>
        <source>Successfully removed permissions from %1 %2.</source>
        <translation>成功從 %1 %2 移除權限。</translation>
    </message>
    <message>
        <source>The active database does not contain an entry with permissions.</source>
        <translation>目前的資料庫中沒有帶有權限的項目。</translation>
    </message>
    <message>
        <source>KeePassXC: New key association request</source>
        <translation>KeePassXC：新的金鑰關聯請求</translation>
    </message>
    <message>
        <source>You have received an association request for the above key.
If you would like to allow it access to your KeePassXC database
give it a unique name to identify and accept it.</source>
        <translation>你已接收到上述金鑰的關聯請求。
如果你允許透過此金鑰存取你的 KeePassXC 資料庫
請取一個唯一識別名並按下接受。</translation>
    </message>
    <message>
        <source>KeePassXC: Overwrite existing key?</source>
        <translation>KeePassXC：覆蓋現有的金鑰？</translation>
    </message>
    <message>
        <source>KeePassXC: Update Entry</source>
        <translation>KeePassXC：更新項目</translation>
    </message>
    <message>
        <source>KeePassXC: Database locked!</source>
        <translation>KeePassXC：資料庫已鎖定！</translation>
    </message>
    <message>
        <source>KeePassXC: Removed keys from database</source>
        <translation>KeePassXC：從資料庫中移除金鑰</translation>
    </message>
    <message>
        <source>KeePassXC: No keys found</source>
        <translation>KeePassXC：找不到金鑰</translation>
    </message>
    <message>
        <source>KeePassXC: Settings not available!</source>
        <translation>KeePassXC：設定不可用！</translation>
    </message>
    <message>
        <source>KeePassXC: Removed permissions</source>
        <translation>KeePassXC：已移除權限</translation>
    </message>
    <message>
        <source>KeePassXC: No entry with permissions found!</source>
        <translation>KeePassXC：找不到帶有權限的項目！</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>應用程式設定</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>設定檔存取錯誤：%1</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>記住最近的資料庫</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>離開時，自動儲存</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>修改後，自動儲存</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>在複製到剪貼簿時最小化</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>新增項目時使用群組圖示</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>全域自動輸入快捷鍵</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>語言</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>顯示工作列圖示</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>將視窗最小化至工作列</translation>
    </message>
    <message>
        <source>Load previous databases on startup</source>
        <translation>啟動時載入之前的資料庫</translation>
    </message>
    <message>
        <source>Automatically reload the database when modified externally</source>
        <translation>當有外部修改時自動重新載入資料庫</translation>
    </message>
    <message>
        <source>Hide window to system tray instead of app exit</source>
        <translation>將視窗最小化至工作列而非關閉程式</translation>
    </message>
    <message>
        <source>Minimize window at application startup</source>
        <translation>程式啟動時視窗最小化</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <source>Remember last key files and security dongles</source>
        <translation>記住最近的金鑰檔案與安全鎖</translation>
    </message>
    <message>
        <source>Don&apos;t mark database as modified for non-data changes (e.g., expanding groups)</source>
        <translation>未變更資料時（例如：擴展群組時）不要將資料庫標記為已修改</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>自動輸入</translation>
    </message>
    <message>
        <source>Use entry title and URL to match windows for global Auto-Type</source>
        <translation>使用項目標題與網址來找尋自動輸入的目標視窗</translation>
    </message>
    <message>
        <source>Always ask before performing Auto-Type</source>
        <translation>在執行自動輸入前始終詢問</translation>
    </message>
    <message>
        <source>Auto-Type delay</source>
        <translation>自動輸入延遲</translation>
    </message>
    <message>
        <source> ms</source>
        <translation>毫秒</translation>
    </message>
    <message>
        <source>Start only a single instance of KeePassXC</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>多久後清除剪貼簿</translation>
    </message>
    <message>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>多久沒有動作之後鎖定資料庫</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>預設以明碼顯示密碼</translation>
    </message>
    <message>
        <source>Lock databases after minimizing the window</source>
        <translation>最小化視窗後鎖定資料庫</translation>
    </message>
    <message>
        <source>Don&apos;t require password repeat when it is visible</source>
        <translation>顯示密碼時不需要重複輸入密碼</translation>
    </message>
    <message>
        <source>Timeouts</source>
        <translation>超時</translation>
    </message>
    <message>
        <source>Convenience</source>
        <translation>便利</translation>
    </message>
    <message>
        <source>Lock databases when session is locked or lid is closed</source>
        <translation>當工作階段鎖定或蓋上螢幕時鎖定資料庫</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>隱私</translation>
    </message>
    <message>
        <source>Use Google as fallback for downloading website icons</source>
        <translation>使用 Google 搜尋作為下載網站圖示的備案</translation>
    </message>
</context>
<context>
    <name>SetupTotpDialog</name>
    <message>
        <source>Setup TOTP</source>
        <translation>安裝 TOTP</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>金鑰：</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>使用自訂設定</translation>
    </message>
    <message>
        <source>Note: Change these settings only if you know what you are doing.</source>
        <translation>注意：了解這些選項之前切勿進行變更。</translation>
    </message>
    <message>
        <source>Time step:</source>
        <translation>時間間隔：</translation>
    </message>
    <message>
        <source>8 digits</source>
        <translation>8 位數</translation>
    </message>
    <message>
        <source>6 digits</source>
        <translation>6 位數</translation>
    </message>
    <message>
        <source>Code size:</source>
        <translation>代碼長度：</translation>
    </message>
    <message>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
</context>
<context>
    <name>TotpDialog</name>
    <message>
        <source>Timed Password</source>
        <translation>定時型密碼</translation>
    </message>
    <message>
        <source>000000</source>
        <translation>000000</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Expires in</source>
        <translation>還剩下</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>解鎖資料庫</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome to KeePassXC</source>
        <translation>歡迎來到 KeePassXC</translation>
    </message>
    <message>
        <source>Start storing your passwords securely in a KeePassXC database</source>
        <translation>開始安全的保存你的密碼到 KeePassXC 資料庫</translation>
    </message>
    <message>
        <source>Create new database</source>
        <translation>建立新的資料庫</translation>
    </message>
    <message>
        <source>Open existing database</source>
        <translation>開啟現有資料庫</translation>
    </message>
    <message>
        <source>Import from KeePass 1</source>
        <translation>從 KeePass 1 匯入</translation>
    </message>
    <message>
        <source>Import from CSV</source>
        <translation>從 CSV 匯入</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>近期的資料庫</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>path to a custom config file</source>
        <translation>自訂設定檔路徑</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>資料庫的金鑰檔案</translation>
    </message>
    <message>
        <source>KeePassXC - cross-platform password manager</source>
        <translation>KeePassXC - 跨平台的密碼管理工具</translation>
    </message>
    <message>
        <source>read password of the database from stdin</source>
        <translation>從 stdin 讀取資料庫密碼</translation>
    </message>
    <message>
        <source>filenames of the password databases to open (*.kdbx)</source>
        <translation>欲開啟的密碼資料庫檔名 (*.kdbx)</translation>
    </message>
    <message>
        <source>Copy a password to the clipboard</source>
        <translation>將密碼複製到剪貼簿</translation>
    </message>
    <message>
        <source>Path of the database.</source>
        <translation>資料庫的路徑。</translation>
    </message>
    <message>
        <source>Use a GUI prompt unlocking the database.</source>
        <translation>使用 GUI 提示來解鎖資料庫。</translation>
    </message>
    <message>
        <source>Name of the entry to clip.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract and print the content of a database.</source>
        <translation>提取與列印資料庫內容。</translation>
    </message>
    <message>
        <source>Path of the database to extract.</source>
        <translation>要提取的資料庫路徑。</translation>
    </message>
    <message>
        <source>Name of the command to execute.</source>
        <translation>要執行的命令的名稱。</translation>
    </message>
    <message>
        <source>List database entries.</source>
        <translation>列出資料庫項目。</translation>
    </message>
    <message>
        <source>Path of the group to list. Default is /</source>
        <translation>要列出的群組路徑。預設是 /</translation>
    </message>
    <message>
        <source>Print the UUIDs of the entries and groups.</source>
        <translation>列印項目與群組的 UUID</translation>
    </message>
    <message>
        <source>Merge two databases.</source>
        <translation>合併兩個資料庫。</translation>
    </message>
    <message>
        <source>Path of the database to merge into.</source>
        <translation>合併時的目標資料庫路徑。</translation>
    </message>
    <message>
        <source>Path of the database to merge from.</source>
        <translation>合併時的來源資料庫路徑。</translation>
    </message>
    <message>
        <source>Use the same password for both database files.</source>
        <translation>在這兩個資料庫檔案使用相同的密碼。</translation>
    </message>
    <message>
        <source>Show a password.</source>
        <translation>顯示密碼。</translation>
    </message>
    <message>
        <source>Name of the entry to show.</source>
        <translation>要顯示的項目名稱。</translation>
    </message>
</context>
</TS>